# coding: utf-8

"""
    

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat

from six import iteritems


class ModelMetricsPK(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_training_ref': 'ModelTrainingRef',
        'lineage_run_ref': 'LineageRunRef',
        'stored_in_schema_ref': 'SchemaRef'
    }

    attribute_map = {
        'model_training_ref': 'modelTrainingRef',
        'lineage_run_ref': 'lineageRunRef',
        'stored_in_schema_ref': 'storedInSchemaRef'
    }

    def __init__(self, model_training_ref=None, lineage_run_ref=None, stored_in_schema_ref=None):
        """
        ModelMetricsPK - a model defined in Swagger
        """

        self._model_training_ref = None
        self._lineage_run_ref = None
        self._stored_in_schema_ref = None

        self.model_training_ref = model_training_ref
        self.lineage_run_ref = lineage_run_ref
        self.stored_in_schema_ref = stored_in_schema_ref

    @property
    def model_training_ref(self):
        """
        Gets the model_training_ref of this ModelMetricsPK.
        Points to the trained model

        :return: The model_training_ref of this ModelMetricsPK.
        :rtype: ModelTrainingRef
        """
        return self._model_training_ref

    @model_training_ref.setter
    def model_training_ref(self, model_training_ref):
        """
        Sets the model_training_ref of this ModelMetricsPK.
        Points to the trained model

        :param model_training_ref: The model_training_ref of this ModelMetricsPK.
        :type: ModelTrainingRef
        """
        if model_training_ref is None:
            raise ValueError("Invalid value for `model_training_ref`, must not be `None`")

        self._model_training_ref = model_training_ref

    @property
    def lineage_run_ref(self):
        """
        Gets the lineage_run_ref of this ModelMetricsPK.
        Points to the lineage run having trained the model and seeing these metrics

        :return: The lineage_run_ref of this ModelMetricsPK.
        :rtype: LineageRunRef
        """
        return self._lineage_run_ref

    @lineage_run_ref.setter
    def lineage_run_ref(self, lineage_run_ref):
        """
        Sets the lineage_run_ref of this ModelMetricsPK.
        Points to the lineage run having trained the model and seeing these metrics

        :param lineage_run_ref: The lineage_run_ref of this ModelMetricsPK.
        :type: LineageRunRef
        """
        if lineage_run_ref is None:
            raise ValueError("Invalid value for `lineage_run_ref`, must not be `None`")

        self._lineage_run_ref = lineage_run_ref

    @property
    def stored_in_schema_ref(self):
        """
        Gets the stored_in_schema_ref of this ModelMetricsPK.
        Points to location of training result (i.e. lineage output schema) which is seeing the metrics (in edge cases a training can have multiple results)

        :return: The stored_in_schema_ref of this ModelMetricsPK.
        :rtype: SchemaRef
        """
        return self._stored_in_schema_ref

    @stored_in_schema_ref.setter
    def stored_in_schema_ref(self, stored_in_schema_ref):
        """
        Sets the stored_in_schema_ref of this ModelMetricsPK.
        Points to location of training result (i.e. lineage output schema) which is seeing the metrics (in edge cases a training can have multiple results)

        :param stored_in_schema_ref: The stored_in_schema_ref of this ModelMetricsPK.
        :type: SchemaRef
        """
        if stored_in_schema_ref is None:
            raise ValueError("Invalid value for `stored_in_schema_ref`, must not be `None`")

        self._stored_in_schema_ref = stored_in_schema_ref

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelMetricsPK):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
